import { DefaultDebugSessionFactory } from '@theia/debug/lib/browser/debug-session-contribution';
import { TerminalService } from '@theia/terminal/lib/browser/base/terminal-service';
import { EditorManager } from '@theia/editor/lib/browser/editor-manager';
import { BreakpointManager } from '@theia/debug/lib/browser/breakpoint/breakpoint-manager';
import { LabelProvider } from '@theia/core/lib/browser/label-provider';
import { MessageClient } from '@theia/core/lib/common/message-service-protocol';
import { OutputChannelManager } from '@theia/output/lib/browser/output-channel';
import { DebugPreferences } from '@theia/debug/lib/browser/debug-preferences';
import { DebugConfigurationSessionOptions } from '@theia/debug/lib/browser/debug-session-options';
import { DebugSession } from '@theia/debug/lib/browser/debug-session';
import { DebugSessionConnection } from '@theia/debug/lib/browser/debug-session-connection';
import { TerminalWidgetOptions, TerminalWidget } from '@theia/terminal/lib/browser/base/terminal-widget';
import { TerminalOptionsExt } from '../../../common/plugin-api-rpc';
import { FileService } from '@theia/filesystem/lib/browser/file-service';
import { DebugContribution } from '@theia/debug/lib/browser/debug-contribution';
import { ContributionProvider } from '@theia/core/lib/common/contribution-provider';
import { WorkspaceService } from '@theia/workspace/lib/browser';
import { PluginChannel } from '../../../common/connection';
export declare class PluginDebugSession extends DebugSession {
    readonly id: string;
    readonly options: DebugConfigurationSessionOptions;
    readonly parentSession: DebugSession | undefined;
    protected readonly connection: DebugSessionConnection;
    protected readonly terminalServer: TerminalService;
    protected readonly editorManager: EditorManager;
    protected readonly breakpoints: BreakpointManager;
    protected readonly labelProvider: LabelProvider;
    protected readonly messages: MessageClient;
    protected readonly fileService: FileService;
    protected readonly terminalOptionsExt: TerminalOptionsExt | undefined;
    protected readonly debugContributionProvider: ContributionProvider<DebugContribution>;
    protected readonly workspaceService: WorkspaceService;
    constructor(id: string, options: DebugConfigurationSessionOptions, parentSession: DebugSession | undefined, connection: DebugSessionConnection, terminalServer: TerminalService, editorManager: EditorManager, breakpoints: BreakpointManager, labelProvider: LabelProvider, messages: MessageClient, fileService: FileService, terminalOptionsExt: TerminalOptionsExt | undefined, debugContributionProvider: ContributionProvider<DebugContribution>, workspaceService: WorkspaceService);
    protected doCreateTerminal(terminalWidgetOptions: TerminalWidgetOptions): Promise<TerminalWidget>;
}
/**
 * Session factory for a client debug session that communicates with debug adapter contributed as plugin.
 * The main difference is to use a connection factory that creates [Channel](#Channel) over Rpc channel.
 */
export declare class PluginDebugSessionFactory extends DefaultDebugSessionFactory {
    protected readonly terminalService: TerminalService;
    protected readonly editorManager: EditorManager;
    protected readonly breakpoints: BreakpointManager;
    protected readonly labelProvider: LabelProvider;
    protected readonly messages: MessageClient;
    protected readonly outputChannelManager: OutputChannelManager;
    protected readonly debugPreferences: DebugPreferences;
    protected readonly connectionFactory: (sessionId: string) => Promise<PluginChannel>;
    protected readonly fileService: FileService;
    protected readonly terminalOptionsExt: TerminalOptionsExt | undefined;
    protected readonly debugContributionProvider: ContributionProvider<DebugContribution>;
    protected readonly workspaceService: WorkspaceService;
    constructor(terminalService: TerminalService, editorManager: EditorManager, breakpoints: BreakpointManager, labelProvider: LabelProvider, messages: MessageClient, outputChannelManager: OutputChannelManager, debugPreferences: DebugPreferences, connectionFactory: (sessionId: string) => Promise<PluginChannel>, fileService: FileService, terminalOptionsExt: TerminalOptionsExt | undefined, debugContributionProvider: ContributionProvider<DebugContribution>, workspaceService: WorkspaceService);
    get(sessionId: string, options: DebugConfigurationSessionOptions, parentSession?: DebugSession): DebugSession;
}
//# sourceMappingURL=plugin-debug-session-factory.d.ts.map